% Example name: Exp2Stochastic
% Description: this script selects stimuli for the design of Experiment 2 in ME95 (as discussed in the manuscript)
% The script will find 2 samples of 24 words that are different on frequency and matched on AoA, length, and imageability
% The optimization uses the stochastic method of annealing 

% Sets the random seed
setSeed(5732);

% Creates a new population for the high frequency sample
highFreqPopulation = population('Exp2HighFreqPopulation.txt','name','highFreqPopulation','isHeader',true,'isFormatting',true);

% Creates a new population for the low frequency sample
lowFreqPopulation = population('Exp2LowFreqPopulation.txt','name','lowFreqPopulation','isHeader',true,'isFormatting',true);

% Creates a new sample of 24 words for the high frequency condition
highFreqSample = sample(24,'name','highFreqSample','outFile','highFreqSampleGREEDY.txt');

% Creates a new sample of 24 words for the low frequency condition
lowFreqSample = sample(24,'name','lowFreqSample','outFile','lowFreqSampleGREEDY.txt');

% Links the samples to the populations from which their items will be drawn
highFreqSample.setPop(highFreqPopulation);
lowFreqSample.setPop(lowFreqPopulation);

% Creates a new SOS optimization
Exp2StochSOS = sos('reportInterval',1000, 'statTestReportStyle','full');

% Adds the two samples to the optimization
Exp2StochSOS.addSample(highFreqSample);
Exp2StochSOS.addSample(lowFreqSample);

% Adds a new constraint: maximize the difference pairwise between the samples on frequency
freqConstraint = Exp2StochSOS.addConstraint('sosObj', Exp2StochSOS, 'name', 'freqConstraint', 'constraintType', 'soft', 'fnc', 'orderedMax', 'stat', 'mean', 'sample1', lowFreqSample, 'sample2', highFreqSample, 's1ColName', 'KFfrequency', 'S2ColName', 'KFfrequency', 'exponent', 2, 'paired', true, 'weight', 1);

% Adds a new constraint: minimize the differences pairwise between the samples on AoA
AoAConstraint = Exp2StochSOS.addConstraint('sosObj', Exp2StochSOS, 'name','AoAConstraint','constraintType', 'soft', 'fnc', 'min', 'stat', 'mean', 'sample1', highFreqSample, 'sample2', lowFreqSample, 's1ColName', 'AoA', 'S2ColName', 'AoA', 'exponent', 2, 'paired', true, 'weight', 1);

% Adds a new constraint: minimize the differences pairwise between the samples on length
lengthConstraint = Exp2StochSOS.addConstraint('sosObj', Exp2StochSOS, 'name', 'lengthConstraint', 'constraintType', 'soft', 'fnc', 'min', 'stat', 'mean', 'sample1', highFreqSample, 'sample2', lowFreqSample, 's1ColName', 'letters', 'S2ColName', 'letters', 'exponent', 2, 'paired', true, 'weight', 100);

% Adds a new constraint: minimize the differences pairwise between the samples on imageability
imageConstraint = Exp2StochSOS.addConstraint('sosObj', Exp2StochSOS, 'name', 'imageConstraint', 'constraintType', 'soft', 'fnc', 'min', 'stat', 'mean', 'sample1', highFreqSample, 'sample2', lowFreqSample, 's1ColName', 'imagery', 'S2ColName', 'imagery', 'exponent', 2, 'paired', true, 'weight', 1);

% Adds a new meta constraint to ensure that differences on frequency are maximized only when the AoA difference has been minimized
metaAoAAndFreqConstraint = Exp2StochSOS.addConstraint('name', 'metaAoAAndFreqConstraint', 'constraintType', 'meta', 'fnc', 'matchCostNotMin', 'constraint1', AoAConstraint, 'constraint2', freqConstraint, 'constraint2costScale', 1.0, 'weight', 1, 'exponent', 2.0);

% Adds a new meta constraint to ensure that differences on frequency are maximized only when the length difference has been minimized
metaLengthAndFreqConstraint = Exp2StochSOS.addConstraint('name', 'metaLengthAndFreqConstraint', 'constraintType', 'meta', 'fnc', 'matchCostNotMin', 'constraint1', lengthConstraint, 'constraint2', freqConstraint, 'constraint2costScale', 1.0, 'weight', 1, 'exponent', 2.0);

% Adds a new meta constraint to ensure that differences on frequency are maximized only when the imageability difference has been minimized
metaImagAndFreqConstraint = Exp2StochSOS.addConstraint('name', 'metaImagAndFreqConstraint', 'constraintType', 'meta', 'fnc', 'matchCostNotMin', 'constraint1', imageConstraint, 'constraint2', freqConstraint, 'constraint2costScale', 1.0, 'weight', 1, 'exponent', 2.0);

% Fills the samples with items selected radomly from the population
Exp2StochSOS.initFillSamples();

% Normalizes the values of the dimensions of interest
Exp2StochSOS.normalizeData();

% Creates a paired samples t-test; test "passes" if frequency differs between the samples, p < .05 
Exp2StochSOS.addttest('name', 'frequencyTest', 'type', 'paired', 'sample1', highFreqSample, 'sample2', lowFreqSample, 's1ColName', 'KFfrequency', 's2ColName', 'KFfrequency', 'desiredpvalCondition', '<=', 'desiredpval',2.5000e-008);

% Creates a paired samples t-test; test "passes" if length is matched between the samples, p > .5 
Exp2StochSOS.addttest('name', 'lengthTest', 'type', 'paired', 'sample1', highFreqSample, 'sample2', lowFreqSample, 's1ColName', 'letters', 's2ColName', 'letters', 'desiredpvalCondition', '=>', 'desiredpval', 1.0);

% Creates a paired samples t-test; test "passes" if AoA is matched between the samples, p > .5
Exp2StochSOS.addttest('name', 'AoATest', 'type', 'paired', 'sample1', highFreqSample, 'sample2', lowFreqSample, 's1ColName', 'AoA', 's2ColName', 'AoA', 'desiredpvalCondition', '=>', 'desiredpval', 0.5);

% Creates a paired samples t-test; test "passes" if imageability is matched between the samples, p > .5
Exp2StochSOS.addttest('name', 'imageabilityTest', 'type', 'paired', 'sample1', highFreqSample, 'sample2', lowFreqSample, 's1ColName', 'imagery', 's2ColName', 'imagery', 'desiredpvalCondition', '=>', 'desiredpval', 0.5);

% Specifies the type of optimization
%Exp2StochSOS.setAnnealSchedule('schedule','exp', 'pDecrease', .402508);

% Increases the maximum number of interations from the default
Exp2StochSOS.maxIt = 1000000;

% Starts the SOS GIO
sos_gui();







